%% Simulate IRFs of NK, GS and extended-GS models 
% call 4 dynare codes
% IRFs in the order of nu_i, nu_a, nu_g, nu_h
% Figure 7

clc
clear

%
set(0,'defaultAxesFontSize',12);
set(0,'defaultAxesFontName','century');
set(0,'defaultTextFontSize',12);
set(0,'defaultTextFontName','century');
%

%% Run dynare code for standard NK model
dynare IRF_NK1106

IRF_NK = [vy_nu_i, vpi_nu_i, vi_nu_i, ...
       vy_nu_a, vpi_nu_a, vi_nu_a, ...
       vy_nu_g, vpi_nu_g, vi_nu_g, ...
       vy_nu_h, vpi_nu_h, vi_nu_h];

save temp_NK IRF_NK

%% Run dynare code for GS model
dynare IRF_GS1106

IRF_GS = [vy_nu_i, vpi_nu_i, vpin_nu_i, vi_nu_i, vh_nu_i, vl_nu_i, vs_nu_i vx_nu_i vq_nu_i ...
       vy_nu_a, vpi_nu_a, vpin_nu_a, vi_nu_a, vh_nu_a, vl_nu_a, vs_nu_a vx_nu_a vq_nu_a ...
       vy_nu_g, vpi_nu_g, vpin_nu_g, vi_nu_g, vh_nu_g, vl_nu_g, vs_nu_g vx_nu_g vq_nu_g ...
       vy_nu_h, vpi_nu_h, vpin_nu_h, vi_nu_h, vh_nu_h, vl_nu_h, vs_nu_h vx_nu_h vq_nu_h];

save temp_GS IRF_GS

%% Run dynare code
% \theta_l = 100
dynare IRF_L1106_100

IRF_100 = [vy_nu_i, vpi_nu_i, vpin_nu_i, vi_nu_i, vh_nu_i, vl_nu_i, vs_nu_i vx_nu_i vq_nu_i ...
       vy_nu_a, vpi_nu_a, vpin_nu_a, vi_nu_a, vh_nu_a, vl_nu_a, vs_nu_a vx_nu_a vq_nu_a ...
       vy_nu_g, vpi_nu_g, vpin_nu_g, vi_nu_g, vh_nu_g, vl_nu_g, vs_nu_g vx_nu_g vq_nu_g ...
       vy_nu_h, vpi_nu_h, vpin_nu_h, vi_nu_h, vh_nu_h, vl_nu_h, vs_nu_h vx_nu_h vq_nu_h];
save temp_100 IRF_100

%% Run dynare code
dynare IRF_L1106

IRF = [vy_nu_i, vpi_nu_i, vpin_nu_i, vi_nu_i, vh_nu_i, vl_nu_i, vs_nu_i vx_nu_i vq_nu_i ...
       vy_nu_a, vpi_nu_a, vpin_nu_a, vi_nu_a, vh_nu_a, vl_nu_a, vs_nu_a vx_nu_a vq_nu_a ...
       vy_nu_g, vpi_nu_g, vpin_nu_g, vi_nu_g, vh_nu_g, vl_nu_g, vs_nu_g vx_nu_g vq_nu_g ...
       vy_nu_h, vpi_nu_h, vpin_nu_h, vi_nu_h, vh_nu_h, vl_nu_h, vs_nu_h vx_nu_h vq_nu_h];
save temp_L IRF

%% Draw graph of IRFs
times= 1:12; 
load temp_NK;
load temp_GS;
load temp_100;

%% compare GS and NK
title_label = {'Output','Inflation \pi_N', 'Interest Rate'};
ncol = 9;
figure
    for k=1:1
    subplot(1,3,1+3*(k-1))
    h=plot(times, IRF_GS(times,1+ncol*(k-1)), 'k.-', times, IRF_NK(times,1+3*(k-1)), 'r--'); 
    title([title_label(1)]);
    xlim([1, 12]);
    %set(h(2),'linewidth',1.5);

    subplot(1,3,2+3*(k-1))
    h=plot(times, IRF_GS(times,3+ncol*(k-1)), 'k.-', times, IRF_NK(times,2+3*(k-1)), 'r--'); 
    title([title_label(2)]);
    xlim([1, 12]);
    %set(h(2),'linewidth',1.5);
    
    subplot(1,3,3+3*(k-1))
    h=plot(times, IRF_GS(times,4+ncol*(k-1)), 'k.-', times, IRF_NK(times,3+3*(k-1)), 'r--');  
    title([title_label(3)]);
    xlim([1, 12]);
    %set(h(2),'linewidth',1.5);
end
legend('GS model', 'NK model (no sales)', 'Location','SouthEast')

%% compare our model and GS
title_label = {'Output','Infl   \pi','Infl   \pi_N','Int Rate','Hours','Loyal','Sale Freq','Real MC','q'};
for k=1:4 % In the order of nu_i, nu_a, nu_g, nu_h
figure
for j = 1:8
    subplot(3,3,j)
    if (j==2) | (j==3) | (j==4)
        h=plot(times, IRF_GS(times,j+ncol*(k-1)), times, IRF(times,j+ncol*(k-1)), 'k.-', times, IRF_100(times,j+ncol*(k-1)), 'r*-');  
    else
        h=plot(times, IRF_GS(times,j+ncol*(k-1)), times, IRF(times,j+ncol*(k-1)), 'k.-', times, IRF_100(times,j+ncol*(k-1)), 'r*-');
    end
    title([title_label(j)]);
    xlim([1, 12]);
    set(h(2),'linewidth',1.5);
end
legend('GS model', 'Model \theta_L=1.7', 'Model \theta_L=100', 'Location','SouthEastOutside')
end

%%
%delete temp_NK.mat;
%delete temp_GS.mat;
%delete temp_100.mat;
%delete temp_L.mat;

