
// Dynare code to replicate GS model
//  modifications are the Taylor rule
//  calibration using matchtargets.m
// vl = vf =0;

clc

var vpi vx vw vl vf vpiw vy vi vs vmu vh vxi vpin vc vq vchi vsale e_a e_g e_h e_i;

// Exogenous variables
varexo nu_i nu_a nu_g nu_h;

parameters mu chi s epsilon eta lambda sigma 
 beta thetac thetah zeta  phip phiw alpha gamma
 phii phipi rho
 thetal
 psi delta
 la lb  psns psnmu sx sl xi varsigma_n
 phil kappa;

// Targeted variables
s = 0.211;
mu = 0.845;
chi = 2.055;

// Parameters of model of sales
tmp0 = matchtargets(mu,chi,s,s);
epsilon = tmp0(1);
eta = tmp0(2);
lambda = tmp0(3);
sigma = tmp0(4);

// Other parameters (monthly calibration)
beta = (0.9975); // subjective discount factor
thetac = 0.333; // intertemporal elasticity of substitution in consumption
thetah = 0.7; //Frisch elasticity of labour supply
zeta = 20; // elasticity of substitution bw differentiated labour inputs
phip = (0.889); // probability of stickiness of normal prices
phiw = (0.889); // probability of wage stickiness
alpha = 0.667; // elasticity of output w.r.t. hours
gamma = (1-alpha)/alpha; // elasticity of marginal cost w.r.t. output
phii = (0.8);  // coefficient on the past interst rate in the Taylor rule
phipi = 1.5; // coefficient on inflation in the Taylor rule
rho = 0.85;
//phil = 0.001;
thetal = 4;

tmp1 = equilaux(epsilon,eta,lambda,mu,s);
psi = tmp1(1);
//x = tmp1(2);
//Delta = tmp1(3);
delta = tmp1(4);

tmp = param_lendo(epsilon, eta, lambda, mu, chi, s, psi, delta);
la = tmp(1);
lb = tmp(2);
psns = tmp(3);
psnmu = tmp(4);
sx = tmp(5);
sl = tmp(6);
xi = tmp(7); 
varsigma_n = tmp(8);
phil = param_steady(epsilon, eta, lambda, mu, chi, s, psi, delta, thetal, alpha);
kappa = (1-phip)*(1-beta*phip)/phip;
//if no sale
//psi = 0; 


model(linear);

vpi = beta*vpi(+1)
 + 1/(1-psi)*(
    kappa*vx + psi*((vx-vx(-1))-beta*(vx(+1)-vx))
    + la*(kappa*vl + (vl-vl(-1))-beta*(vl(+1)-vl)));
    
vpin = vpi - psi/(1-psi)*(vx-vx(-1)) - la/(1-psi)*(vl-vl(-1));
//vpin = beta*vpin(+1) + kappa/(1-psi)*(vx + la*vl);


vx = 1/(1+gamma*delta)*vw + gamma/(1+gamma*delta)*(vy-lb*vl);

vpiw = beta*vpiw(+1)
 + (1-phiw)*(1-beta*phiw)/phiw/(1+zeta/thetah)*(
  (1/thetac+1/(1+gamma*delta)/thetah/alpha)*vy
 - (1+delta/(1+gamma*delta)/thetah/alpha)*vw
 - 1/thetah/alpha*e_a + e_h - 1/thetac*e_g
 - (lb/thetah/(1+gamma*delta)/alpha + 1/thetah*thetal*phil*lambda/(1-lambda))*vl
 + (1/thetac-1)*(vf - epsilon*(vx + 1/(eta-epsilon)/(1-lambda)*vl))
 );

vw-vw(-1) = vpiw - vpi;

vy = vy(+1) - thetac*(vi-vpi(+1))
 + (e_g - e_g(+1))
 + (1-thetac)*(
  (vf(+1) - epsilon*(vx(+1) + 1/(eta-epsilon)/(1-lambda)*vl(+1)))
  - (vf - epsilon*(vx + 1/(eta-epsilon)/(1-lambda)*vl))
 );

vi = phii*vi(-1) + (1-phii)*(phipi*vpin) - e_i;


// share of loyal custmoers is endogenous
// if share of loyal custmoers is exo
0 = vl;
vf =0;

vxi = psns*s*vs + psnmu*s*vmu;

vmu = 1/(1-psi)*(vx + la*vl);

vchi = -varsigma_n*vmu;

vsale = 1/(s*chi+1-s)*vs + (1-s)/(s*chi+1-s)*vchi;

s*vs = sx*vx + sl*vl;

vh = 1/(1+gamma*delta)*(vy - delta*vw - lb*vl)/alpha - e_a/alpha;

vc = vy + vf - epsilon*(vx + 1/(eta-epsilon)/(1-lambda)*vl) - e_g;

vq = 1/(1+gamma*delta)*(vy - delta*vw - lb*vl);

e_a = rho*e_a(-1) + nu_a;
e_g = rho*e_g(-1) + nu_g;
e_h = rho*e_h(-1) + nu_h;
e_i =  nu_i;

end;

//steady;

shocks;
var nu_i; stderr 1;
var nu_a; stderr 1;
var nu_g; stderr 1;
var nu_h; stderr 1;
end;


stoch_simul(irf=24, nograph);
//stoch_simul(irf=24) vy, vq, vpi, vpin, vi, vl, vh, vs, vx;
//TMP = [vy_e_i, vpi_e_i, vpin_e_i, vi_e_i, vh_e_i, vl_e_i, vs_e_i vw_e_i vx_e_i, vy_nu_a, vpi_nu_a, vpin_nu_a, vi_nu_a, vh_nu_a, vl_nu_a, vs_nu_a vw_nu_a vx_nu_a];
