function [residual, g1, g2, g3] = IRF_L1106_100_dynamic(y, x, params, steady_state, it_)
%
% Status : Computes dynamic model for Dynare
%
% Inputs :
%   y         [#dynamic variables by 1] double    vector of endogenous variables in the order stored
%                                                 in M_.lead_lag_incidence; see the Manual
%   x         [M_.exo_nbr by nperiods] double     matrix of exogenous variables (in declaration order)
%                                                 for all simulation periods
%   params    [M_.param_nbr by 1] double          vector of parameter values in declaration order
%   it_       scalar double                       time period for exogenous variables for which to evaluate the model
%
% Outputs:
%   residual  [M_.endo_nbr by 1] double    vector of residuals of the dynamic model equations in order of 
%                                          declaration of the equations
%   g1        [M_.endo_nbr by #dynamic variables] double    Jacobian matrix of the dynamic model equations;
%                                                           rows: equations in order of declaration
%                                                           columns: variables in order stored in M_.lead_lag_incidence
%   g2        [M_.endo_nbr by (#dynamic variables)^2] double   Hessian matrix of the dynamic model equations;
%                                                              rows: equations in order of declaration
%                                                              columns: variables in order stored in M_.lead_lag_incidence
%   g3        [M_.endo_nbr by (#dynamic variables)^3] double   Third order derivative matrix of the dynamic model equations;
%                                                              rows: equations in order of declaration
%                                                              columns: variables in order stored in M_.lead_lag_incidence
%
%
% Warning : this file is generated automatically by Dynare
%           from model file (.mod)

%
% Model equations
%

residual = zeros(21, 1);
T14 = 1/(1-params(20));
T53 = 1/(1+params(15)*params(21));
T77 = (1-params(13))*(1-params(8)*params(13))/params(13)/(1+params(11)/params(10));
T79 = 1/params(9);
T83 = T79+T53/params(10)/params(14);
T87 = params(21)/(1+params(15)*params(21))/params(10)/params(14);
T92 = 1/params(10)/params(14);
T94 = T92*y(25);
T111 = 1/params(10)*params(19)*params(30)*params(6)/(1-params(6));
T112 = params(23)/params(10)/(1+params(15)*params(21))/params(14)+T111;
T121 = 1/(params(5)-params(4))/(1-params(6));
T165 = 1/params(10)/(1+params(15)*params(21))/params(14);
T200 = params(6)*params(5)/(params(5)-1)/(1+params(6)*params(28)-params(6));
lhs =y(8);
rhs =params(8)*y(29)+T14*(params(31)*y(9)+params(20)*(y(9)-y(1)-params(8)*(y(30)-y(9)))+params(22)*(params(31)*y(11)+y(11)-y(3)-params(8)*(y(31)-y(11))));
residual(1)= lhs-rhs;
lhs =y(20);
rhs =y(8)-(y(9)-y(1))*params(20)/(1-params(20))-(y(11)-y(3))*params(22)/(1-params(20));
residual(2)= lhs-rhs;
lhs =y(9);
rhs =T53*y(10)+params(15)/(1+params(15)*params(21))*(y(14)-y(11)*params(23));
residual(3)= lhs-rhs;
lhs =y(13);
rhs =params(8)*y(33)+T77*(y(14)*T83-y(10)*(1+T87)-T94+y(27)-T79*y(26)-y(11)*T112+(T79-1)*(y(12)-params(4)*(y(9)+y(11)*T121)));
residual(4)= lhs-rhs;
lhs =y(10)-y(2);
rhs =y(13)-y(8);
residual(5)= lhs-rhs;
lhs =y(14);
rhs =y(34)-params(9)*(y(15)-y(29))+y(26)-y(35)+(1-params(9))*(y(32)-params(4)*(y(30)+y(31)*T121)-(y(12)-params(4)*(y(9)+y(11)*T121)));
residual(6)= lhs-rhs;
lhs =y(15);
rhs =params(16)*y(4)+(1-params(16))*y(20)*params(17)-y(28);
residual(7)= lhs-rhs;
lhs =0;
rhs =(T79-1)*(y(12)-params(4)*(y(9)+y(11)*T121))+y(27)+y(14)*(T79+T165-1)-y(10)*T87-T94-y(26)*(T79-1)-y(11)*(T111+params(23)*T165+params(6)*(params(19)-1)/(1-params(6)))+params(28)/(1-params(28))*y(19)+y(12)*(params(5)-1)/params(5);
residual(8)= lhs-rhs;
lhs =y(12);
rhs =T200*(params(28)*y(19)-y(11)*(1-params(28)));
residual(9)= lhs-rhs;
lhs =y(19);
rhs =params(24)*params(3)*y(16)+params(3)*params(25)*y(17);
residual(10)= lhs-rhs;
lhs =y(17);
rhs =T14*(y(9)+params(22)*y(11));
residual(11)= lhs-rhs;
lhs =y(23);
rhs =y(17)*(-params(29));
residual(12)= lhs-rhs;
lhs =y(24);
rhs =y(16)*1/(1+params(3)*params(2)-params(3))+y(23)*(1-params(3))/(1+params(3)*params(2)-params(3));
residual(13)= lhs-rhs;
lhs =params(3)*y(16);
rhs =y(9)*params(26)+y(11)*params(27);
residual(14)= lhs-rhs;
lhs =y(18);
rhs =T53*(y(14)-params(21)*y(10)-y(11)*params(23))/params(14)-y(25)/params(14);
residual(15)= lhs-rhs;
lhs =y(21);
rhs =y(14)+y(12)-params(4)*(y(9)+y(11)*T121)-y(26);
residual(16)= lhs-rhs;
lhs =y(22);
rhs =T53*(y(14)-params(21)*y(10)-y(11)*params(23));
residual(17)= lhs-rhs;
lhs =y(25);
rhs =params(18)*y(5)+x(it_, 2);
residual(18)= lhs-rhs;
lhs =y(26);
rhs =params(18)*y(6)+x(it_, 3);
residual(19)= lhs-rhs;
lhs =y(27);
rhs =params(18)*y(7)+x(it_, 4);
residual(20)= lhs-rhs;
lhs =y(28);
rhs =x(it_, 1);
residual(21)= lhs-rhs;
if nargout >= 2,
  g1 = zeros(21, 39);

  %
  % Jacobian matrix
  %

  g1(1,8)=1;
  g1(1,29)=(-params(8));
  g1(1,1)=(-(T14*(-params(20))));
  g1(1,9)=(-(T14*(params(31)+params(20)*(1-(-params(8))))));
  g1(1,30)=(-(T14*params(20)*(-params(8))));
  g1(1,3)=(-(T14*(-params(22))));
  g1(1,11)=(-(T14*params(22)*(1+params(31)-(-params(8)))));
  g1(1,31)=(-(T14*params(22)*(-params(8))));
  g1(2,8)=(-1);
  g1(2,1)=(-(params(20)/(1-params(20))));
  g1(2,9)=params(20)/(1-params(20));
  g1(2,3)=(-(params(22)/(1-params(20))));
  g1(2,11)=params(22)/(1-params(20));
  g1(2,20)=1;
  g1(3,9)=1;
  g1(3,10)=(-T53);
  g1(3,11)=(-(params(15)/(1+params(15)*params(21))*(-params(23))));
  g1(3,14)=(-(params(15)/(1+params(15)*params(21))));
  g1(4,9)=(-(T77*(T79-1)*(-params(4))));
  g1(4,10)=(-(T77*(-(1+T87))));
  g1(4,11)=(-(T77*((-T112)+(T79-1)*(-(params(4)*T121)))));
  g1(4,12)=(-(T77*(T79-1)));
  g1(4,13)=1;
  g1(4,33)=(-params(8));
  g1(4,14)=(-(T77*T83));
  g1(4,25)=(-(T77*(-T92)));
  g1(4,26)=(-(T77*(-T79)));
  g1(4,27)=(-T77);
  g1(5,8)=1;
  g1(5,2)=(-1);
  g1(5,10)=1;
  g1(5,13)=(-1);
  g1(6,29)=(-params(9));
  g1(6,9)=(-(params(4)*(1-params(9))));
  g1(6,30)=(-((1-params(9))*(-params(4))));
  g1(6,11)=(-((1-params(9))*params(4)*T121));
  g1(6,31)=(-((1-params(9))*(-(params(4)*T121))));
  g1(6,12)=1-params(9);
  g1(6,32)=(-(1-params(9)));
  g1(6,14)=1;
  g1(6,34)=(-1);
  g1(6,15)=params(9);
  g1(6,26)=(-1);
  g1(6,35)=1;
  g1(7,4)=(-params(16));
  g1(7,15)=1;
  g1(7,20)=(-((1-params(16))*params(17)));
  g1(7,28)=1;
  g1(8,9)=(-((T79-1)*(-params(4))));
  g1(8,10)=T87;
  g1(8,11)=(-((T79-1)*(-(params(4)*T121))-(T111+params(23)*T165+params(6)*(params(19)-1)/(1-params(6)))));
  g1(8,12)=(-(T79-1+(params(5)-1)/params(5)));
  g1(8,14)=(-(T79+T165-1));
  g1(8,19)=(-(params(28)/(1-params(28))));
  g1(8,25)=T92;
  g1(8,26)=T79-1;
  g1(8,27)=(-1);
  g1(9,11)=(-(T200*(-(1-params(28)))));
  g1(9,12)=1;
  g1(9,19)=(-(params(28)*T200));
  g1(10,16)=(-(params(24)*params(3)));
  g1(10,17)=(-(params(3)*params(25)));
  g1(10,19)=1;
  g1(11,9)=(-T14);
  g1(11,11)=(-(T14*params(22)));
  g1(11,17)=1;
  g1(12,17)=params(29);
  g1(12,23)=1;
  g1(13,16)=(-(1/(1+params(3)*params(2)-params(3))));
  g1(13,23)=(-((1-params(3))/(1+params(3)*params(2)-params(3))));
  g1(13,24)=1;
  g1(14,9)=(-params(26));
  g1(14,11)=(-params(27));
  g1(14,16)=params(3);
  g1(15,10)=(-(T53*(-params(21))/params(14)));
  g1(15,11)=(-(T53*(-params(23))/params(14)));
  g1(15,14)=(-(T53/params(14)));
  g1(15,18)=1;
  g1(15,25)=1/params(14);
  g1(16,9)=params(4);
  g1(16,11)=params(4)*T121;
  g1(16,12)=(-1);
  g1(16,14)=(-1);
  g1(16,21)=1;
  g1(16,26)=1;
  g1(17,10)=(-(T53*(-params(21))));
  g1(17,11)=(-(T53*(-params(23))));
  g1(17,14)=(-T53);
  g1(17,22)=1;
  g1(18,5)=(-params(18));
  g1(18,25)=1;
  g1(18,37)=(-1);
  g1(19,6)=(-params(18));
  g1(19,26)=1;
  g1(19,38)=(-1);
  g1(20,7)=(-params(18));
  g1(20,27)=1;
  g1(20,39)=(-1);
  g1(21,28)=1;
  g1(21,36)=(-1);
end
if nargout >= 3,
  %
  % Hessian matrix
  %

  g2 = sparse([],[],[],21,1521);
end
if nargout >= 4,
  %
  % Third order derivatives
  %

  g3 = sparse([],[],[],21,59319);
end
end
