function [residual, g1, g2] = IRF_L1106_static(y, x, params)
%
% Status : Computes static model for Dynare
%
% Inputs : 
%   y         [M_.endo_nbr by 1] double    vector of endogenous variables in declaration order
%   x         [M_.exo_nbr by 1] double     vector of exogenous variables in declaration order
%   params    [M_.param_nbr by 1] double   vector of parameter values in declaration order
%
% Outputs:
%   residual  [M_.endo_nbr by 1] double    vector of residuals of the static model equations 
%                                          in order of declaration of the equations
%   g1        [M_.endo_nbr by M_.endo_nbr] double    Jacobian matrix of the static model equations;
%                                                     columns: variables in declaration order
%                                                     rows: equations in order of declaration
%   g2        [M_.endo_nbr by (M_.endo_nbr)^2] double   Hessian matrix of the static model equations;
%                                                       columns: variables in declaration order
%                                                       rows: equations in order of declaration
%
%
% Warning : this file is generated automatically by Dynare
%           from model file (.mod)

residual = zeros( 21, 1);

%
% Model equations
%

T13 = 1/(1-params(20));
T33 = 1/(1+params(15)*params(21));
T56 = (1-params(13))*(1-params(8)*params(13))/params(13)/(1+params(11)/params(10));
T58 = 1/params(9);
T62 = T58+T33/params(10)/params(14);
T66 = params(21)/(1+params(15)*params(21))/params(10)/params(14);
T71 = 1/params(10)/params(14);
T73 = T71*y(18);
T90 = 1/params(10)*params(19)*params(30)*params(6)/(1-params(6));
T91 = params(23)/params(10)/(1+params(15)*params(21))/params(14)+T90;
T100 = 1/(params(5)-params(4))/(1-params(6));
T103 = params(4)*(y(2)+y(4)*T100);
T105 = (T58-1)*(y(5)-T103);
T129 = 1/params(10)/(1+params(15)*params(21))/params(14);
T164 = params(6)*params(5)/(params(5)-1)/(1+params(6)*params(28)-params(6));
lhs =y(1);
rhs =y(1)*params(8)+T13*(params(31)*y(2)+params(22)*params(31)*y(4));
residual(1)= lhs-rhs;
lhs =y(13);
rhs =y(1);
residual(2)= lhs-rhs;
lhs =y(2);
rhs =T33*y(3)+params(15)/(1+params(15)*params(21))*(y(7)-y(4)*params(23));
residual(3)= lhs-rhs;
lhs =y(6);
rhs =params(8)*y(6)+T56*(y(7)*T62-y(3)*(1+T66)-T73+y(20)-T58*y(19)-y(4)*T91+T105);
residual(4)= lhs-rhs;
lhs =0;
rhs =y(6)-y(1);
residual(5)= lhs-rhs;
lhs =y(7);
rhs =y(7)-params(9)*(y(8)-y(1));
residual(6)= lhs-rhs;
lhs =y(8);
rhs =y(8)*params(16)+(1-params(16))*y(13)*params(17)-y(21);
residual(7)= lhs-rhs;
lhs =0;
rhs =T105+y(20)+y(7)*(T58+T129-1)-y(3)*T66-T73-y(19)*(T58-1)-y(4)*(T90+params(23)*T129+params(6)*(params(19)-1)/(1-params(6)))+params(28)/(1-params(28))*y(12)+y(5)*(params(5)-1)/params(5);
residual(8)= lhs-rhs;
lhs =y(5);
rhs =T164*(params(28)*y(12)-y(4)*(1-params(28)));
residual(9)= lhs-rhs;
lhs =y(12);
rhs =params(24)*params(3)*y(9)+params(3)*params(25)*y(10);
residual(10)= lhs-rhs;
lhs =y(10);
rhs =T13*(y(2)+params(22)*y(4));
residual(11)= lhs-rhs;
lhs =y(16);
rhs =y(10)*(-params(29));
residual(12)= lhs-rhs;
lhs =y(17);
rhs =y(9)*1/(1+params(3)*params(2)-params(3))+y(16)*(1-params(3))/(1+params(3)*params(2)-params(3));
residual(13)= lhs-rhs;
lhs =params(3)*y(9);
rhs =y(2)*params(26)+y(4)*params(27);
residual(14)= lhs-rhs;
lhs =y(11);
rhs =T33*(y(7)-params(21)*y(3)-y(4)*params(23))/params(14)-y(18)/params(14);
residual(15)= lhs-rhs;
lhs =y(14);
rhs =y(7)+y(5)-T103-y(19);
residual(16)= lhs-rhs;
lhs =y(15);
rhs =T33*(y(7)-params(21)*y(3)-y(4)*params(23));
residual(17)= lhs-rhs;
lhs =y(18);
rhs =y(18)*params(18)+x(2);
residual(18)= lhs-rhs;
lhs =y(19);
rhs =y(19)*params(18)+x(3);
residual(19)= lhs-rhs;
lhs =y(20);
rhs =y(20)*params(18)+x(4);
residual(20)= lhs-rhs;
lhs =y(21);
rhs =x(1);
residual(21)= lhs-rhs;
if ~isreal(residual)
  residual = real(residual)+imag(residual).^2;
end
if nargout >= 2,
  g1 = zeros(21, 21);

  %
  % Jacobian matrix
  %

  g1(1,1)=1-params(8);
  g1(1,2)=(-(T13*params(31)));
  g1(1,4)=(-(T13*params(31)*params(22)));
  g1(2,1)=(-1);
  g1(2,13)=1;
  g1(3,2)=1;
  g1(3,3)=(-T33);
  g1(3,4)=(-(params(15)/(1+params(15)*params(21))*(-params(23))));
  g1(3,7)=(-(params(15)/(1+params(15)*params(21))));
  g1(4,2)=(-(T56*(T58-1)*(-params(4))));
  g1(4,3)=(-(T56*(-(1+T66))));
  g1(4,4)=(-(T56*((-T91)+(T58-1)*(-(params(4)*T100)))));
  g1(4,5)=(-(T56*(T58-1)));
  g1(4,6)=1-params(8);
  g1(4,7)=(-(T56*T62));
  g1(4,18)=(-(T56*(-T71)));
  g1(4,19)=(-(T56*(-T58)));
  g1(4,20)=(-T56);
  g1(5,1)=1;
  g1(5,6)=(-1);
  g1(6,1)=(-params(9));
  g1(6,8)=params(9);
  g1(7,8)=1-params(16);
  g1(7,13)=(-((1-params(16))*params(17)));
  g1(7,21)=1;
  g1(8,2)=(-((T58-1)*(-params(4))));
  g1(8,3)=T66;
  g1(8,4)=(-((T58-1)*(-(params(4)*T100))-(T90+params(23)*T129+params(6)*(params(19)-1)/(1-params(6)))));
  g1(8,5)=(-(T58-1+(params(5)-1)/params(5)));
  g1(8,7)=(-(T58+T129-1));
  g1(8,12)=(-(params(28)/(1-params(28))));
  g1(8,18)=T71;
  g1(8,19)=T58-1;
  g1(8,20)=(-1);
  g1(9,4)=(-(T164*(-(1-params(28)))));
  g1(9,5)=1;
  g1(9,12)=(-(params(28)*T164));
  g1(10,9)=(-(params(24)*params(3)));
  g1(10,10)=(-(params(3)*params(25)));
  g1(10,12)=1;
  g1(11,2)=(-T13);
  g1(11,4)=(-(T13*params(22)));
  g1(11,10)=1;
  g1(12,10)=params(29);
  g1(12,16)=1;
  g1(13,9)=(-(1/(1+params(3)*params(2)-params(3))));
  g1(13,16)=(-((1-params(3))/(1+params(3)*params(2)-params(3))));
  g1(13,17)=1;
  g1(14,2)=(-params(26));
  g1(14,4)=(-params(27));
  g1(14,9)=params(3);
  g1(15,3)=(-(T33*(-params(21))/params(14)));
  g1(15,4)=(-(T33*(-params(23))/params(14)));
  g1(15,7)=(-(T33/params(14)));
  g1(15,11)=1;
  g1(15,18)=1/params(14);
  g1(16,2)=params(4);
  g1(16,4)=params(4)*T100;
  g1(16,5)=(-1);
  g1(16,7)=(-1);
  g1(16,14)=1;
  g1(16,19)=1;
  g1(17,3)=(-(T33*(-params(21))));
  g1(17,4)=(-(T33*(-params(23))));
  g1(17,7)=(-T33);
  g1(17,15)=1;
  g1(18,18)=1-params(18);
  g1(19,19)=1-params(18);
  g1(20,20)=1-params(18);
  g1(21,21)=1;
  if ~isreal(g1)
    g1 = real(g1)+2*imag(g1);
  end
end
if nargout >= 3,
  %
  % Hessian matrix
  %

  g2 = sparse([],[],[],21,441);
end
end
