
// Dynare code for standard NK model
//  modifications are the Taylor rule


clc

var vpi vx vw vpiw vy vi e_a e_g e_h e_i;

// Exogenous variables
varexo nu_i nu_a nu_g nu_h;

parameters mu chi s epsilon eta lambda sigma  alpha gamma
 beta thetac thetah zeta  phip phiw 
 phii phipi rho
 thetal
 psi delta
 la lb  psns psnmu sx sl xi varsigma_n
 phil kappa;


// Other parameters (monthly calibration)
beta = (0.9975); // subjective discount factor
thetac = 0.333; // intertemporal elasticity of substitution in consumption
thetah = 0.7; //Frisch elasticity of labour supply
zeta = 20; // elasticity of substitution bw differentiated labour inputs
phip = (0.889); // probability of stickiness of normal prices
phiw = (0.889); // probability of wage stickiness
alpha = 0.667; // elasticity of output w.r.t. hours
gamma = (1-alpha)/alpha; // elasticity of marginal cost w.r.t. output
phii = (0.8);  // coefficient on the past interst rate in the Taylor rule
phipi = 1.5; // coefficient on inflation in the Taylor rule
rho = 0.85;

delta = 0;
kappa = (1-phip)*(1-beta*phip)/phip;

model(linear);

vpi = beta*vpi(+1)
 + kappa*vx;
    
vx = 1/(1+gamma*delta)*vw + gamma/(1+gamma*delta)*vy;

vpiw = beta*vpiw(+1)
 + (1-phiw)*(1-beta*phiw)/phiw/(1+zeta/thetah)*(
  (1/thetac+1/(1+gamma*delta)/thetah/alpha)*vy
 - (1+delta/(1+gamma*delta)/thetah/alpha)*vw
 - 1/thetah/alpha*e_a + e_h - 1/thetac*e_g
  );
 
vw-vw(-1) = vpiw - vpi;

vy = vy(+1) - thetac*(vi-vpi(+1))
 + (e_g - e_g(+1));

vi = phii*vi(-1) + (1-phii)*(phipi*vpi) - e_i;


e_a = rho*e_a(-1) + nu_a;
e_g = rho*e_g(-1) + nu_g;
e_h = rho*e_h(-1) + nu_h;
e_i =  nu_i;

end;

//steady;

shocks;
var nu_i; stderr 1;
var nu_a; stderr 1;
var nu_g; stderr 1;
var nu_h; stderr 1;
end;


stoch_simul(irf=24, nograph);
//stoch_simul(irf=24) vy, vq, vpi, vpin, vi, vl, vh, vs, vx;
//TMP = [vy_e_i, vpi_e_i, vpin_e_i, vi_e_i, vh_e_i, vl_e_i, vs_e_i vw_e_i vx_e_i, vy_nu_a, vpi_nu_a, vpin_nu_a, vi_nu_a, vh_nu_a, vl_nu_a, vs_nu_a vw_nu_a vx_nu_a];
