function [residual, g1, g2, g3] = IRF_NK1106_dynamic(y, x, params, steady_state, it_)
%
% Status : Computes dynamic model for Dynare
%
% Inputs :
%   y         [#dynamic variables by 1] double    vector of endogenous variables in the order stored
%                                                 in M_.lead_lag_incidence; see the Manual
%   x         [M_.exo_nbr by nperiods] double     matrix of exogenous variables (in declaration order)
%                                                 for all simulation periods
%   params    [M_.param_nbr by 1] double          vector of parameter values in declaration order
%   it_       scalar double                       time period for exogenous variables for which to evaluate the model
%
% Outputs:
%   residual  [M_.endo_nbr by 1] double    vector of residuals of the dynamic model equations in order of 
%                                          declaration of the equations
%   g1        [M_.endo_nbr by #dynamic variables] double    Jacobian matrix of the dynamic model equations;
%                                                           rows: equations in order of declaration
%                                                           columns: variables in order stored in M_.lead_lag_incidence
%   g2        [M_.endo_nbr by (#dynamic variables)^2] double   Hessian matrix of the dynamic model equations;
%                                                              rows: equations in order of declaration
%                                                              columns: variables in order stored in M_.lead_lag_incidence
%   g3        [M_.endo_nbr by (#dynamic variables)^3] double   Third order derivative matrix of the dynamic model equations;
%                                                              rows: equations in order of declaration
%                                                              columns: variables in order stored in M_.lead_lag_incidence
%
%
% Warning : this file is generated automatically by Dynare
%           from model file (.mod)

%
% Model equations
%

residual = zeros(10, 1);
T42 = (1-params(15))*(1-params(10)*params(15))/params(15)/(1+params(13)/params(12));
T48 = 1/params(11)+1/(1+params(9)*params(21))/params(12)/params(8);
T53 = 1+params(21)/(1+params(9)*params(21))/params(12)/params(8);
T57 = 1/params(12)/params(8);
lhs =y(6);
rhs =params(10)*y(16)+params(31)*y(7);
residual(1)= lhs-rhs;
lhs =y(7);
rhs =1/(1+params(9)*params(21))*y(8)+params(9)/(1+params(9)*params(21))*y(10);
residual(2)= lhs-rhs;
lhs =y(9);
rhs =params(10)*y(17)+T42*(y(10)*T48-y(8)*T53-T57*y(12)+y(14)-1/params(11)*y(13));
residual(3)= lhs-rhs;
lhs =y(8)-y(1);
rhs =y(9)-y(6);
residual(4)= lhs-rhs;
lhs =y(10);
rhs =y(18)-params(11)*(y(11)-y(16))+y(13)-y(19);
residual(5)= lhs-rhs;
lhs =y(11);
rhs =params(16)*y(2)+(1-params(16))*y(6)*params(17)-y(15);
residual(6)= lhs-rhs;
lhs =y(12);
rhs =params(18)*y(3)+x(it_, 2);
residual(7)= lhs-rhs;
lhs =y(13);
rhs =params(18)*y(4)+x(it_, 3);
residual(8)= lhs-rhs;
lhs =y(14);
rhs =params(18)*y(5)+x(it_, 4);
residual(9)= lhs-rhs;
lhs =y(15);
rhs =x(it_, 1);
residual(10)= lhs-rhs;
if nargout >= 2,
  g1 = zeros(10, 23);

  %
  % Jacobian matrix
  %

  g1(1,6)=1;
  g1(1,16)=(-params(10));
  g1(1,7)=(-params(31));
  g1(2,7)=1;
  g1(2,8)=(-(1/(1+params(9)*params(21))));
  g1(2,10)=(-(params(9)/(1+params(9)*params(21))));
  g1(3,8)=(-(T42*(-T53)));
  g1(3,9)=1;
  g1(3,17)=(-params(10));
  g1(3,10)=(-(T42*T48));
  g1(3,12)=(-(T42*(-T57)));
  g1(3,13)=(-(T42*(-(1/params(11)))));
  g1(3,14)=(-T42);
  g1(4,6)=1;
  g1(4,1)=(-1);
  g1(4,8)=1;
  g1(4,9)=(-1);
  g1(5,16)=(-params(11));
  g1(5,10)=1;
  g1(5,18)=(-1);
  g1(5,11)=params(11);
  g1(5,13)=(-1);
  g1(5,19)=1;
  g1(6,6)=(-((1-params(16))*params(17)));
  g1(6,2)=(-params(16));
  g1(6,11)=1;
  g1(6,15)=1;
  g1(7,3)=(-params(18));
  g1(7,12)=1;
  g1(7,21)=(-1);
  g1(8,4)=(-params(18));
  g1(8,13)=1;
  g1(8,22)=(-1);
  g1(9,5)=(-params(18));
  g1(9,14)=1;
  g1(9,23)=(-1);
  g1(10,15)=1;
  g1(10,20)=(-1);
end
if nargout >= 3,
  %
  % Hessian matrix
  %

  g2 = sparse([],[],[],10,529);
end
if nargout >= 4,
  %
  % Third order derivatives
  %

  g3 = sparse([],[],[],10,12167);
end
end
