function [residual, g1, g2] = IRF_NK1106_static(y, x, params)
%
% Status : Computes static model for Dynare
%
% Inputs : 
%   y         [M_.endo_nbr by 1] double    vector of endogenous variables in declaration order
%   x         [M_.exo_nbr by 1] double     vector of exogenous variables in declaration order
%   params    [M_.param_nbr by 1] double   vector of parameter values in declaration order
%
% Outputs:
%   residual  [M_.endo_nbr by 1] double    vector of residuals of the static model equations 
%                                          in order of declaration of the equations
%   g1        [M_.endo_nbr by M_.endo_nbr] double    Jacobian matrix of the static model equations;
%                                                     columns: variables in declaration order
%                                                     rows: equations in order of declaration
%   g2        [M_.endo_nbr by (M_.endo_nbr)^2] double   Hessian matrix of the static model equations;
%                                                       columns: variables in declaration order
%                                                       rows: equations in order of declaration
%
%
% Warning : this file is generated automatically by Dynare
%           from model file (.mod)

residual = zeros( 10, 1);

%
% Model equations
%

T40 = (1-params(15))*(1-params(10)*params(15))/params(15)/(1+params(13)/params(12));
T46 = 1/params(11)+1/(1+params(9)*params(21))/params(12)/params(8);
T51 = 1+params(21)/(1+params(9)*params(21))/params(12)/params(8);
T55 = 1/params(12)/params(8);
lhs =y(1);
rhs =y(1)*params(10)+params(31)*y(2);
residual(1)= lhs-rhs;
lhs =y(2);
rhs =1/(1+params(9)*params(21))*y(3)+params(9)/(1+params(9)*params(21))*y(5);
residual(2)= lhs-rhs;
lhs =y(4);
rhs =params(10)*y(4)+T40*(y(5)*T46-y(3)*T51-T55*y(7)+y(9)-1/params(11)*y(8));
residual(3)= lhs-rhs;
lhs =0;
rhs =y(4)-y(1);
residual(4)= lhs-rhs;
lhs =y(5);
rhs =y(5)-params(11)*(y(6)-y(1));
residual(5)= lhs-rhs;
lhs =y(6);
rhs =y(6)*params(16)+(1-params(16))*y(1)*params(17)-y(10);
residual(6)= lhs-rhs;
lhs =y(7);
rhs =y(7)*params(18)+x(2);
residual(7)= lhs-rhs;
lhs =y(8);
rhs =y(8)*params(18)+x(3);
residual(8)= lhs-rhs;
lhs =y(9);
rhs =y(9)*params(18)+x(4);
residual(9)= lhs-rhs;
lhs =y(10);
rhs =x(1);
residual(10)= lhs-rhs;
if ~isreal(residual)
  residual = real(residual)+imag(residual).^2;
end
if nargout >= 2,
  g1 = zeros(10, 10);

  %
  % Jacobian matrix
  %

  g1(1,1)=1-params(10);
  g1(1,2)=(-params(31));
  g1(2,2)=1;
  g1(2,3)=(-(1/(1+params(9)*params(21))));
  g1(2,5)=(-(params(9)/(1+params(9)*params(21))));
  g1(3,3)=(-(T40*(-T51)));
  g1(3,4)=1-params(10);
  g1(3,5)=(-(T40*T46));
  g1(3,7)=(-(T40*(-T55)));
  g1(3,8)=(-(T40*(-(1/params(11)))));
  g1(3,9)=(-T40);
  g1(4,1)=1;
  g1(4,4)=(-1);
  g1(5,1)=(-params(11));
  g1(5,6)=params(11);
  g1(6,1)=(-((1-params(16))*params(17)));
  g1(6,6)=1-params(16);
  g1(6,10)=1;
  g1(7,7)=1-params(18);
  g1(8,8)=1-params(18);
  g1(9,9)=1-params(18);
  g1(10,10)=1;
  if ~isreal(g1)
    g1 = real(g1)+2*imag(g1);
  end
end
if nargout >= 3,
  %
  % Hessian matrix
  %

  g2 = sparse([],[],[],10,100);
end
end
