%%%%%%%%%%%%%%%%%
% Investigate the effects of permanent shock on steady state equilibrium
% for Figrues 4 and 6
%%%%%%%%%%%%%%%%%
clc
clear
close all

%
set(0,'defaultAxesFontSize',12);
set(0,'defaultAxesFontName','century');
set(0,'defaultTextFontSize',12);
set(0,'defaultTextFontName','century');
%

%%

% initialization
% Targeted variables
s = 0.211;
mu = 0.845;
chi = 2.055;

%%
% Parameters of model of sales
tmp0 = matchtargets(mu,chi,s,s);
epsilon = tmp0(1)
eta = tmp0(2)
lambda = tmp0(3)
sigma = tmp0(4)

% Other parameters (monthly calibration)
beta = (0.9975); % subjective discount factor
thetac = 0.333; % intertemporal elasticity of substitution in consumption
thetah = 0.7; % Frisch elasticity of labour supply
zeta = 20; % elasticity of substitution bw differentiated labour inputs
alpha = 0.667; % elasticity of output w.r.t. hours
gamma = (1-alpha)/alpha; % elasticity of marginal cost w.r.t. output
thetal = 1.7; 

param = [mu chi s epsilon eta lambda sigma beta thetac thetah zeta alpha gamma thetal];

tmp1 = equilaux(epsilon,eta,lambda,mu,s);
psi = tmp1(1);
delta = tmp1(4);
phil = param_steady(epsilon, eta, lambda, mu, chi, s, psi, delta, thetal, alpha)
    
%%
% if flag == {1, 2, 3} then {e_a, e_h, e_g} is non-zero
Rsq = [];

flag = 3; 
steadystate_change170206
Rsq = [Rsq; stats(1) stats9213(1)];
result_series = zeros(3,tsample,7);
result_series(flag,:,:) = result_benchmark;

flag = 2;
steadystate_change170206
Rsq = [Rsq; stats(1) stats9213(1)];
result_series(flag,:,:) = result_benchmark;

flag = 1;
steadystate_change170206
Rsq = [Rsq; stats(1) stats9213(1)];
result_series(flag,:,:) = result_benchmark;

%% Draw graph of sales
figure
subplot(3,3,1)
h=plot(times, vh, 'k-'); 
title('Hours');
xlim([1980 2014]);
set(h(1),'linewidth',1.5);

subplot(3,3,2)
jj = 1;
h=plot(times, s_data, times, result_series(3,:,jj), 'k-', times(1:5:31), result_series(2,1:5:31,jj), 'r*', times(1:5:31), result_series(1,1:5:31,jj), 'm+', ...
    times, result_series(2,:,jj), 'r-', times, result_series(1,:,jj), 'm-');
title('Freq of sales');
xlim([1980 2014]);
ylim([0. 0.4])
set(h(2),'linewidth',1.5);

subplot(3,3,3)
jj = 2;
h=plot(times, disc_data, times, result_series(3,:,jj), 'k-', times(1:5:31), result_series(2,1:5:31,jj), 'r*', times(1:5:31), result_series(1,1:5:31,jj), 'm+', ...
    times, result_series(2,:,jj), 'r-', times, result_series(1,:,jj), 'm-');
title('Mag of sales');
xlim([1980 2014]);
set(h(2),'linewidth',1.5);

subplot(3,3,4)
jj = 3;
h=plot(times, chi_data, times, result_series(3,:,jj), 'k-', times(1:5:31), result_series(2,1:5:31,jj), 'r*', times(1:5:31), result_series(1,1:5:31,jj), 'm+', ...
    times, result_series(2,:,jj), 'r-', times, result_series(1,:,jj), 'm-');
title('Q ratio');
xlim([1980 2014]);
set(h(2),'linewidth',1.5);

subplot(3,3,5)
jj = 4;
h=plot(times, sale_data, times, result_series(3,:,jj), 'k-', times(1:5:31), result_series(2,1:5:31,jj), 'r*', times(1:5:31), result_series(1,1:5:31,jj), 'm+', ...
    times, result_series(2,:,jj), 'r-', times, result_series(1,:,jj), 'm-');
title('Rev ratio');
xlim([1980 2014]);
ylim([0.15 0.6])
set(h(2),'linewidth',1.5);
legend('Actual', 'Model (benchmark Z      ^d_t)',  'Model (Z   ^h_t)',  'Model (Z   ^a_t)' ,'Location','SouthEast')

subplot(3,3,6)
jj = 5;
h=plot(times, result_series(3,:,jj), 'k-', times(1:5:31), result_series(2,1:5:31,jj), 'r*', times(1:5:31), result_series(1,1:5:31,jj), 'm+', ...
    times, result_series(2,:,jj), 'r-', times, result_series(1,:,jj), 'm-');
title('Loyal');
xlim([1980 2014]);
set(h(1),'linewidth',1.5);

subplot(3,3,7)
jj = 6;
h=plot(times, result_series(3,:,jj), 'k-', times(1:5:31), result_series(2,1:5:31,jj), 'r*', times(1:5:31), result_series(1,1:5:31,jj), 'm+', ...
    times, result_series(2,:,jj), 'r-', times, result_series(1,:,jj), 'm-');
title('Elasticity');
xlim([1980 2014]);
set(h(1),'linewidth',1.5);

% GDP
subplot(3,3,8)
jj = 7;
h=plot(times(2:end), dvy_data, times(2:end), result_series(3,2:end,jj), 'k-', times(2:5:32), result_series(2,2:5:32,jj), 'r*', times(2:5:32), result_series(1,2:5:32,jj), 'm+', ...
    times(2:end), result_series(2,2:end,jj), 'r-', times(2:end), result_series(1,2:end,jj), 'm-');
title('GDP chg');
xlim([1980 2014]);
set(h(2),'linewidth',1.5);


