%%%%%%%%%%%%%%%%%
% Investigate the effects of permanent shock on steady state equilibrium
%%%%%%%%%%%%%%%%%

%%
v0 = zeros(1,11);
eval('run ..\macrodata.m') % load actual vh
% from 1981:2Q to 2013:3Q
% repeat every year (every 4 quarters)
nn = 2012-1982+1;

vh = vh - mean(vh);

vh0 = sum(vh(1:3))/3;
vy0 = sum(vy(1:3))/3;
[y fval] = fsolve(@(x) steadystate_change_func170206(param, vh0, x, flag), v0);
yvec = [y vh0 vy0];
for ii=1:nn
    vh0 = sum(vh(4*(ii-1)+1:4*ii))/4;
    vy0 = sum(vy(4*(ii-1)+1:4*ii))/4;
    [y fval] = fsolve(@(x) steadystate_change_func170206(param, vh0, x, flag), v0);
    yvec = [yvec ; y vh0 vy0];
end
vh0 = sum(vh(end-2:end))/3;
vy0 = sum(vy(end-2:end))/3;
[y fval] = fsolve(@(x) steadystate_change_func170206(param, vh0, x, flag), v0);
yvec = [yvec ; y vh0 vy0];

vs = yvec(:,1);
vl = yvec(:,2);
vmu = yvec(:,4);
vy = yvec(:,7);
vchi =  yvec(:,9);
vsale =  yvec(:,10);
vshock = yvec(:,11);
vh = yvec(:,12);
vy_data = yvec(:,13); vy_data = vy_data - mean(vy_data);

if flag == 3
    save('yvec_results', 'yvec');
end

%% Add mean to sales-related variables

times= 1981:2013; 
times_sales= 1988:2013; % time when the value of sales actual data exist
tsample = size(times,2);
subsample = size(times,2)-size(times_sales,2)+1:tsample; % sample that has the value of sales actual data
subsample0 = 1:size(times,2)-size(times_sales,2); % sample that has no value of sales actual data

s_model = s*exp(vs-mean(vs(subsample)));
disc_model = (1-mu)*exp(-(vmu-mean(vmu(subsample))));
chi_model = chi*exp(vchi-mean(vchi(subsample)));
sale_model = s*chi/(1-s+s*chi)*exp(vsale-mean(vsale(subsample)));
l_model = lambda*exp(vl-mean(vl(subsample)));

%% load actual sales variables

load ..\sales_q.txt;
% sales_q is from 1988:2Q to 2013:3Q
nn = 2012-1989+1;
sales_a = sum(sales_q(1:3,:),1)/3;
for ii=1:nn
    sales_a = [sales_a; sum(sales_q(4*ii:4*ii+3,:),1)/4];
end
sales_a = [sales_a; sum(sales_q(end-2:end,:),1)/3];
s_data = [NaN.*subsample0'; s + sales_a(:,1) - mean(sales_a(:,1))];
disc_data = [NaN.*subsample0'; (1-mu) + sales_a(:,2)-mean(sales_a(:,2))];
chi_data = [NaN.*subsample0'; chi + sales_a(:,3) - mean(sales_a(:,3))];
sale_data = [NaN.*subsample0'; s*chi/(1-s+s*chi) + sales_a(:,4)-mean(sales_a(:,4))];

%% Draw graph of sales
figure
subplot(3,3,1)
h=plot(times, vh, 'k-'); 
title('Hours');
xlim([1980 2014]);
set(h(1),'linewidth',1.5);

subplot(3,3,2)
h=plot(times, s_data, times, s_model, 'k-', times, s*ones(tsample,1), 'r--'); 
title('Freq of sales');
xlim([1980 2014]);
ylim([0.1 0.3])
set(h(2),'linewidth',1.5);

subplot(3,3,3)
h=plot(times, disc_data, times, disc_model, 'k-', times, (1-mu)*ones(tsample,1), 'r--');
title('Mag of sales');
xlim([1980 2014]);
set(h(2),'linewidth',1.5);

subplot(3,3,4)
h=plot(times, chi_data, times, chi_model, 'k-', times, chi*ones(tsample,1), 'r--'); 
title('Q ratio');
xlim([1980 2014]);
set(h(2),'linewidth',1.5);

subplot(3,3,5)
h=plot(times, sale_data, times, sale_model, 'k-', times, s*chi/(1-s+s*chi)*ones(tsample,1), 'r--'); 
title('Rev ratio');
xlim([1980 2014]);
ylim([0.25 0.45])
set(h(2),'linewidth',1.5);
legend('Actual', 'Model',  'GS Model','Location','SouthEast')

subplot(3,3,6)
h=plot(times, l_model, 'k-', times, lambda*ones(tsample,1), 'r--'); 
title('Loyal');
xlim([1980 2014]);
set(h(1),'linewidth',1.5);

% evaluate weighted average of elasticity
elast_model = l_model*epsilon + (1-l_model)*eta;
elast_GSmodel = lambda*epsilon + (1-lambda)*eta;
subplot(3,3,7)
h=plot(times, elast_model, 'k-', times, elast_GSmodel*ones(tsample,1), 'r--'); 
title('Elasticity');
xlim([1980 2014]);
set(h(1),'linewidth',1.5);

% GDP
vy_model = vy-mean(vy(subsample));
dvy_model = vy_model(2:end)-vy_model(1:end-1);
dvy_data = vy_data(2:end)-vy_data(1:end-1);
subplot(3,3,8)
h=plot(times(2:end), dvy_data, times(2:end), dvy_model, 'k-'); 
title('GDP chg');
xlim([1980 2014]);
set(h(2),'linewidth',1.5);

dvy_model1 = [0; dvy_model];
result_benchmark = [s_model, disc_model,chi_model, sale_model,l_model, elast_model, dvy_model1]; 
if flag == 3
    save('steadystate_change', 'result_benchmark');
end

X= [ones(size(dvy_data)), dvy_model];
[b,bint,r,rint,stats] = regress(dvy_data, X);

%% from 1992 to 2013
ad = 11;
X9213= X(ad:end, :); 
[b9213,bint9213,r9203,rint9213,stats9213] = regress(dvy_data(ad:end), X9213);
