%%%%%%%%%%%%%%%%%
% Investigate the effects of permanent shock on steady state equilibrium
%%%%%%%%%%%%%%%%%
function y = steadystate_change_func151130(param, vh, v0, flag)
%% end variables
vs = v0(1);
vl = v0(2);
vx = v0(3);
vmu = v0(4);
vf = v0(5);
vxi = v0(6);
vy = v0(7);
vw = v0(8);
vchi = v0(9);
vsale = v0(10);
vshock = v0(11);

if flag == 1
    e_a = vshock; e_g = 0; e_h = 0;
elseif flag == 2
    e_h = vshock; e_a = 0; e_g = 0;
else
    e_g = vshock; e_a = 0; e_h = 0;
end

%% parameters
mu = param(1);
chi = param(2); 
s  = param(3);
epsilon  = param(4);
eta  = param(5);
lambda  = param(6);
sigma  = param(7);
beta  = param(8);
thetac  = param(9);
thetah  = param(10);
zeta  = param(11);
alpha  = param(12);
gamma  = param(13);
thetal  = param(14);

tmp1 = equilaux(epsilon,eta,lambda,mu,s);
psi = tmp1(1);
%x = tmp1(2);
%Delta = tmp1(3);
delta = tmp1(4);

tmp = param_lendo(epsilon, eta, lambda, mu, chi, s, psi, delta);
la = tmp(1);
lb = tmp(2);
psns = tmp(3);
psnmu = tmp(4);
sx = tmp(5);
sl = tmp(6);
xi = tmp(7); 
varsigma_mu = tmp(8);
phil = param_steady(epsilon, eta, lambda, mu, chi, s, psi, delta, thetal, alpha);

%%
% model

y1 = vx + la*vl ;
    
y2 = vx - 1/(1+gamma*delta)*vw - gamma/(1+gamma*delta)*(vy-lb*vl);

y3 = (1/thetac+1/(1+gamma*delta)/thetah/alpha)*vy ...
 - (1+delta/(1+gamma*delta)/thetah/alpha)*vw ...
 - 1/thetah/alpha*e_a + e_h - 1/thetac*e_g ...
 - (lb/thetah/(1+gamma*delta)/alpha + 1/thetah*thetal*phil*lambda/(1-lambda))*vl ...
 + (1/thetac-1)*(vf - epsilon*(vx + 1/(eta-epsilon)/(1-lambda)*vl)) ;
 
y4 = (1/thetac + 1/thetah/(1+gamma*delta)/alpha - 1)*vy ...
 - delta/(1+gamma*delta)/thetah/alpha*vw ...
 - 1/thetah/alpha*e_a + e_h - (1/thetac-1)*e_g ...
 - (1/thetah/(1+gamma*delta)/alpha*lb + (thetal-1)*lambda/(1-lambda) + 1/thetah*thetal*phil*lambda/(1-lambda))*vl ...
 + (1/thetac-1)*(vf - epsilon*(vx + 1/(eta-epsilon)/(1-lambda)*vl)) ...
 + xi/(1-xi)*vxi ...
 + (eta-1)/eta*vf;

y5 = -vf + eta/(eta-1)*lambda/(lambda*xi+1-lambda)*( xi*vxi - (1-xi)*vl );

y6 = - vxi + psns*s*vs + psnmu*s*vmu;

y7 = - vmu + 1/(1-psi)*(vx + la*vl);

y8 = -s*vs + sx*vx + sl*vl;

y9 = -vh + 1/(1+gamma*delta)*(vy - delta*vw - lb*vl)/alpha - e_a/alpha;

y10 = -vchi  - varsigma_mu*vmu;

y11 = -vsale + 1/(s*chi+1-s)*vs + (1-s)/(s*chi+1-s)*vchi;

y = [y1 y2 y3 y4 y5 y6 y7 y8 y9 y10 y11];

