%%%%%%%%%%%%%%%%%
% Investigate the effects of permanent shock on steady state equilibrium

% For two kinds of robustness checks
%  Given obtained path of shocks, we assume 
% 1. s (sale frequency) is constant because firms do not adjust it optimally 

%%%%%%%%%%%%%%%%%
function y = steadystate_change_func_robust1(param, vshock, v0, flag)
%% end variables
vs = v0(1);   
vl = v0(2);
vx = v0(3);
vmu = v0(4);
vf = v0(5);
vxi = v0(6);
vy = v0(7);
vw = v0(8);
vchi = v0(9);
vsale = v0(10);
vh = v0(11);  % new
%vshock = v0(11);   % new

if flag == 1
    e_a = vshock; e_g = 0; e_h = 0;
elseif flag == 2
    e_h = vshock; e_a = 0; e_g = 0;
else
    e_g = vshock; e_a = 0; e_h = 0;
end

%% parameters
mu = param(1); 
chi = param(2); 
s  = param(3); 
epsilon  = param(4);
eta  = param(5);
lambda  = param(6);
sigma  = param(7);
beta  = param(8);
thetac  = param(9);
thetah  = param(10);
zeta  = param(11);
alpha  = param(12);
gamma  = param(13);
thetal  = param(14);

tmp1 = equilaux(epsilon,eta,lambda,mu,s);
psi = tmp1(1);
%x = tmp1(2);
%Delta = tmp1(3);
delta = tmp1(4);

tmp = param_lendo(epsilon, eta, lambda, mu, chi, s, psi, delta);
la = tmp(1);
lb = tmp(2);
psns = tmp(3);
psnmu = tmp(4);
sx = tmp(5);
sl = tmp(6);
xi = tmp(7); 
varsigma_mu = tmp(8);
phil = param_steady(epsilon, eta, lambda, mu, chi, s, psi, delta, thetal, alpha);


%GS's parameters
thetab = s/(s+(1-s)*mu^(eta-1)); % [E.8]
psib = 1/(eta-1)*(1-mu^(eta-1))/(s+(1-s)*mu^(eta-1)); % [E.8]
psil = 1/(epsilon-1)*(1-mu^(epsilon-1))/(s+(1-s)*mu^(epsilon-1)); % [E.10]
hbar = (s+(1-s)*mu^(epsilon-1))^(1/(epsilon-1))/(s+(1-s)*mu^(eta-1))^(1/(eta-1)); % [E.11]
omega = (1-lambda)/(1-lambda+lambda*hbar^(epsilon-1)); % [E.11]
psip = (1-omega)*psil + omega*psib; % [E.12]
p_vs = 1/(s+(1-s)*mu^(eta-1))^((eta-epsilon)/(eta-1)); % one line below [E.33] 
p_vn = mu^(eta-epsilon)*p_vs; % [E.34]
thetap = (1-omega)*thetal + omega*thetab;
rho_n = lambda*(1-lambda)*(eta-epsilon)*p_vn/(lambda*epsilon+(1-lambda)*eta*p_vn)/(lambda*(epsilon-1)+(1-lambda)*(eta-1)*p_vn);

%%
% model
pb_p = (thetab-thetap)/(1-thetap)*vx + (1-thetab)/(1-thetap)*lambda*((1-omega)/lambda - omega/(1-lambda))/(epsilon-1)*vl;
pn_p = 1/(1-thetab)*pb_p - thetab/(1-thetab)*vx;
qs = lambda*(1-p_vs)/(lambda + (1-lambda)*p_vs)*vl ...
    - (1-lambda)*p_vs/(lambda + (1-lambda)*p_vs)*(eta-epsilon)*(vx-pb_p) ...
    -epsilon*vx + vy;
qn = lambda*(1-p_vn)/(lambda + (1-lambda)*p_vn)*vl ...
    - (1-lambda)*p_vn/(lambda + (1-lambda)*p_vn)*(eta-epsilon)*(pn_p-pb_p) ...
    -epsilon*pn_p + vy;
vq = (s*chi*qs + (1-s)*qn)/(s*chi+1-s);

y1 = vmu - (vx - pn_p);

y2 = (pn_p - vx) - rho_n*(eta-epsilon)*(pn_p-pb_p) + 1/(1-lambda)*rho_n*vl;

y3 = vx - vw - gamma*vq;

y4 = e_h + 1/thetah*vh - 1/thetah*thetal*phil/(1-lambda)*lambda*vl ...
    + 1/thetac*( vy + vf - epsilon*pb_p - e_g) ...
    - vw - vf + epsilon*pb_p;

y5 = -vf + eta/(eta-1)*lambda/(lambda*xi+1-lambda)*( xi*vxi - (1-xi)*vl );

y6 = - vxi + psnmu*s*vmu;

y7 = vy - vw - e_g + (thetal-1)*lambda/(1-lambda)*vl - xi/(1-xi)*vxi - (eta-1)/eta*vf;

y8 = vs;

y9 = -vh + ( vq - e_a )/alpha;

y10 = -vchi -varsigma_mu*vmu;

y11 = -vsale + (1-s)/(s*chi+1-s)*vchi;


y = [y1 y2 y3 y4 y5 y6 y7 y8 y9 y10 y11];

