% plot time-series Figures 2 and 3
% compute correlations using band-pass filtered series Table 4

clear all;
clc;
tic;

rmpath('C:\dynare\4.4.3\matlab\missing\stats')

%
set(0,'defaultAxesFontSize',12);
set(0,'defaultAxesFontName','century');
set(0,'defaultTextFontSize',12);
set(0,'defaultTextFontName','century');
%

%% initial values
tsize = 308;
sample_price = 1:tsize; % starts from Mar 1988 to Oct 2013
times= 1988+3/12:1/12:2013+10/12;
bp1 = 3*6; %36; % band pass filter
bp2 = 3*32; %86; % band pass filter
mm0 = 6; % omit first and last samples for BP

%% load macro variables
load ..\data\macrodata.txt; 
title_macro = {'Unemp', 'Hours', 'Employed', 'IIP', 'CPI', ...
    'Lead', 'Coinc', 'Lag'};
%for jj=1:size(macrodata,2);
for jj=1:size(macrodata,2);
    macrodata_bp(:,jj) = bpass(macrodata(1+mm0:end-mm0,jj), bp1, bp2);
end

%% load micro prices
micro_struct = []; 
% micro_struct structure with T * N * i * j * k, where
 % i=1 mode and i=2 vshape
 % j=1 42days and j=2 7days (window)
 % k=1 all products, k=2 food, and k=3 domestic
 
filename = strcat('..\data\Sale4_mode_d42.txt'); % sale freq, sale mag, Q ratio, Revenue ratio
microdata = load(filename); 
tsize_d42 = size(microdata,1);
if tsize > tsize_d42
    tt = floor( (tsize-tsize_d42)/2 ); 
    microdata = [NaN*ones(tt,6); microdata; NaN*ones(tsize-tsize_d42-tt,6)];
end        
micro_struct = reshape(microdata, size(microdata,1), [], 1, 1, 1); 
filename = strcat('..\data\Sale4_vshape_d42.txt');
microdata = load(filename);
if tsize > tsize_d42
    tt = floor( (tsize-tsize_d42)/2 ); 
    microdata = [NaN*ones(tt,6); microdata; NaN*ones(tsize-tsize_d42-tt,6)];
end
micro_struct(:,:,2,1,1) = microdata;
filename = strcat('..\data\Sale4_mode_d7.txt');
microdata = load(filename);
tsize_d7 = size(microdata,1);
micro_struct(:,:,1,2,1) = microdata;
filename = strcat('..\data\Sale4_vshape_d7.txt');
microdata = load(filename);
micro_struct(:,:,2,2,1) = microdata;

filename = strcat('..\data\Sale2_food_mode_d42.txt');
microdata = [load(filename) zeros(tsize_d42,4)];
if tsize > tsize_d42
    tt = floor( (tsize-tsize_d42)/2 ); 
    microdata = [NaN*ones(tt,6); microdata; NaN*ones(tsize-tsize_d42-tt,6)];
end
micro_struct(:,:,1,1,2) = microdata; 
filename = strcat('..\data\Sale2_food_vshape_d42.txt');
microdata = [load(filename) zeros(tsize_d42,4)];
if tsize > tsize_d42
    tt = floor( (tsize-tsize_d42)/2 ); 
    microdata = [NaN*ones(tt,6); microdata; NaN*ones(tsize-tsize_d42-tt,6)];
end
micro_struct(:,:,2,1,2) = microdata; 
filename = strcat('..\data\Sale2_domestic_mode_d42.txt');
microdata = [load(filename) zeros(tsize_d42,4)];
if tsize > tsize_d42
    tt = floor( (tsize-tsize_d42)/2 ); 
    microdata = [NaN*ones(tt,6); microdata; NaN*ones(tsize-tsize_d42-tt,6)];
end
micro_struct(:,:,1,1,3) = microdata;
filename = strcat('..\data\Sale2_domestic_vshape_d42.txt');
microdata = [load(filename) zeros(tsize_d42,4)];
if tsize > tsize_d42
    tt = floor( (tsize-tsize_d42)/2 ); 
    microdata = [NaN*ones(tt,6); microdata; NaN*ones(tsize-tsize_d42-tt,6)];
end
micro_struct(:,:,2,1,3) = microdata;

filename = strcat('..\data\Sale2_food_mode_d7.txt');
microdata = [load(filename) zeros(tsize_d7,4)];
micro_struct(:,:,1,2,2) = microdata; 
filename = strcat('..\data\Sale2_food_vshape_d7.txt');
microdata = [load(filename) zeros(tsize_d7,4)];
micro_struct(:,:,2,2,2) = microdata; 
filename = strcat('..\data\Sale2_domestic_mode_d7.txt');
microdata = [load(filename) zeros(tsize_d7,4)];
micro_struct(:,:,1,2,3) = microdata;
filename = strcat('..\data\Sale2_domestic_vshape_d7.txt');
microdata = [load(filename) zeros(tsize_d7,4)];
micro_struct(:,:,2,2,3) = microdata;

%% Draw graphs

%% Weighted quantile
i = 1;
mean_tab = times';
component_bp = [];
correl_freq_tab = zeros(size(macrodata_bp,2), 2, 2, 3);
correl_mag_tab = zeros(size(macrodata_bp,2), 2, 2, 3);
for i=1:2 % sale filter
    for j=1:2 % window days
        for k=1:3 % products
            
    temp = reshape(micro_struct(:,:,i,j,k), tsize, 6);
    temp_freq = temp(:,1); % freq only
    temp_mag = temp(:,2); % mag only
    temp_freq_bp = bpass(temp_freq(1+mm0:end-mm0,:),bp1,bp2);
    temp_mag_bp = bpass(temp_mag(1+mm0:end-mm0,:),bp1,bp2);
    
    [correl_freq pval] = corr(macrodata_bp, temp_freq_bp); % correlation with macro variables
    [correl_mag pval] = corr(macrodata_bp, temp_mag_bp); % correlation with macro variables
    
    % correlation significant level
    % 95%: 0.3879, 90%: 0.3316 % see correl_significantlevel.m
    
    correl_freq_tab(:,i,j,k) = correl_freq;
    correl_mag_tab(:,i,j,k) = correl_mag;
        end
    end
end

correl_freq_tab2 = [correl_freq_tab(:,1,1,1) correl_freq_tab(:,2,1,1) correl_freq_tab(:,1,2,1) correl_freq_tab(:,2,2,1) ...
    correl_freq_tab(:,1,1,2) correl_freq_tab(:,1,1,3) correl_freq_tab(:,2,1,2) correl_freq_tab(:,2,1,3) ... 
    correl_freq_tab(:,1,2,2) correl_freq_tab(:,1,2,3) correl_freq_tab(:,2,2,2) correl_freq_tab(:,2,2,3) ];
correl_freq_tab2 = reshape(correl_freq_tab2, [size(macrodata,2), 12]);
correl_mag_tab2 = [correl_mag_tab(:,1,1,1) correl_mag_tab(:,2,1,1) correl_mag_tab(:,1,2,1) correl_mag_tab(:,2,2,1) ...
    correl_mag_tab(:,1,1,2) correl_mag_tab(:,1,1,3) correl_mag_tab(:,2,1,2) correl_mag_tab(:,2,1,3) ...
    correl_mag_tab(:,1,2,2) correl_mag_tab(:,1,2,3) correl_mag_tab(:,2,2,2) correl_mag_tab(:,2,2,3) ];
correl_mag_tab2 = reshape(correl_mag_tab2, [size(macrodata,2), 12]);

fileID = fopen('Correlations.txt','w+');
fprintf(fileID,'%6s \n', 'Frequency of sales');
fprintf(fileID,'%6s \t %6s \t %6s \t %6s \t %6s \t %6s \t %6s \t %6s \t %6s \t %6s \t %6s \t %6s \t %6s \n', 'Filter', 'mode','V-shaped','mode','V-shaped', 'mode','mode','V-shaped','V-shaped','mode','mode','V-shaped','V-shaped');
fprintf(fileID,'%6s \t %6s \t %6s \t %6s \t %6s \t %6s \t %6s \t %6s \t %6s \t %6s \t %6s \t %6s \t %6s \n', 'Window', '42d','42d','7d','7d','42d','42d','42d','42d','7d','7d','7d','7d');
fprintf(fileID,'%6s \t %6s \t %6s \t %6s \t %6s \t %6s \t %6s \t %6s \t %6s \t %6s \t %6s \t %6s \t %6s \n', 'Goods', 'all','all','all','all', 'food','domestic','food','domestic', 'food','domestic','food','domestic');
fprintf(fileID,'%6s \n', 'Macro variables');

for jj=1:size(macrodata,2);
    fprintf(fileID,'%6s \t %6.3f \t %6.3f \t %6.3f \t %6.3f \t %6.3f \t %6.3f \t %6.3f \t %6.3f \t %6.3f \t %6.3f \t %6.3f \t %6.3f \n', title_macro{jj}, correl_freq_tab2(jj,:));
end

fprintf(fileID,'\n \n');

fprintf(fileID,'%6s \n', 'Magnitude of sales discounts');
fprintf(fileID,'%6s \t %6s \t %6s \t %6s \t %6s \t %6s \t %6s \t %6s \t %6s \t %6s \t %6s \t %6s \t %6s \n', 'Filter', 'mode','V-shaped','mode','V-shaped', 'mode','mode','V-shaped','V-shaped', 'mode','mode','V-shaped','V-shaped');
fprintf(fileID,'%6s \t %6s \t %6s \t %6s \t %6s \t %6s \t %6s \t %6s \t %6s \t %6s \t %6s \t %6s \t %6s \n', 'Window', '42d','42d','7d','7d','42d','42d','42d','42d','7d','7d','7d','7d');
fprintf(fileID,'%6s \t %6s \t %6s \t %6s \t %6s \t %6s \t %6s \t %6s \t %6s \t %6s \t %6s \t %6s \t %6s \n', 'Goods', 'all','all','all','all', 'food','domestic','food','domestic', 'food','domestic','food','domestic');
fprintf(fileID,'%6s \n', 'Macro variables');

for jj=1:size(macrodata,2);
     fprintf(fileID,'%6s \t %6.3f \t %6.3f \t %6.3f \t %6.3f \t %6.3f \t %6.3f  \t %6.3f \t %6.3f \t %6.3f \t %6.3f \t %6.3f \t %6.3f \n', title_macro{jj}, correl_mag_tab2(jj,:));
end

fclose(fileID);

%% Graph of sales-related variables

figure(1)
subplot(2,2,1)
p=plot(times, micro_struct(:,1,1,1,1), 'k-', times, micro_struct(:,1,2,1,1), 'r-', times, micro_struct(:,1,1,2,1), '--'); % choose column for sales freq
t=title('Frequency of sales');
set(t, 'FontSize', 12);
set(p(1), 'LineWidth', 2);
xlim([1988 2014]);

subplot(2,2,2)
p=plot(times, micro_struct(:,2,1,1,1), 'k-', times, micro_struct(:,2,2,1,1), 'r-', times, micro_struct(:,2,1,2,1), '--');
t=title({'Magnitude of'; 'sales discounts'});
set(t, 'FontSize', 12);
xlim([1988 2014]);
set(p(1), 'LineWidth', 2);

subplot(2,2,3)
p=plot(times, micro_struct(:,3,1,1,1), 'k-', times, micro_struct(:,3,2,1,1), 'r-', times, micro_struct(:,3,1,2,1), '--');
t=title({'Quantity ratio of'; 'sales to regular'});
set(t, 'FontSize', 12);
xlim([1988 2014]);
set(p(1), 'LineWidth', 2);

subplot(2,2,4)
p=plot(times, micro_struct(:,4,1,1,1), 'k-', times, micro_struct(:,4,2,1,1), 'r-', times, micro_struct(:,4,1,2,1), '--');
t=title({'Revenue ratio'; 'of sales'});
set(t, 'FontSize', 12);
xlim([1988 2014]);
set(p(1), 'LineWidth', 2);

legend('mode 42d', 'V-shaped 42d', 'mode 7d')

%% Graph for processed food and domestic articles
figure(3)
subplot(2,2,1)
p=plot(times, micro_struct(:,1,1,1,2), 'k-', times, micro_struct(:,1,2,1,2), 'r-', times, micro_struct(:,1,1,2,2), '--'); % choose column for sales freq
t=title({'Frequency of sales'; '(processed food)'});
set(t, 'FontSize', 12);
set(p(1), 'LineWidth', 2);
xlim([1988 2014]);

subplot(2,2,2)
p=plot(times, micro_struct(:,1,1,1,3), 'k-', times, micro_struct(:,1,2,1,3), 'r-', times, micro_struct(:,1,1,2,3), '--'); % choose column for sales freq
t=title({'  '; '(domestic articles)'});
set(t, 'FontSize', 12);
set(p(1), 'LineWidth', 2);
xlim([1988 2014]);

subplot(2,2,3)
p=plot(times, micro_struct(:,2,1,1,2), 'k-', times, micro_struct(:,2,2,1,2), 'r-', times, micro_struct(:,2,1,2,2), '--');
t=title({'Magnitude of sales discounts'; '(processed food)'});
set(t, 'FontSize', 12);
xlim([1988 2014]);
set(p(1), 'LineWidth', 2);

subplot(2,2,4)
p=plot(times, micro_struct(:,2,1,1,3), 'k-', times, micro_struct(:,2,2,1,3), 'r-', times, micro_struct(:,2,1,2,3), '--');

t=title({'  '; '(domestic articles)'});
set(t, 'FontSize', 12);
xlim([1988 2014]);
set(p(1), 'LineWidth', 2);

legend('mode 42d', 'V-shaped 42d', 'mode 7d')


%% Graph of sales-related variables
figure(2)
subplot(2,1,1)
[AX, H1, H2] = plotyy(times, micro_struct(:,1,1,1,1),  times, exp(macrodata(:,1)), 'plot');
set(get(AX(1),'Ylabel'),'String','Frequency of sales') 
set(get(AX(2),'Ylabel'),'String','Unemployment rate') 
set(H1,'LineStyle','-')
set(H2,'LineStyle','-')
set(H1, 'LineWidth', 2);
set(H1, 'Color', 'k');
set(H2, 'Color', 'r');
set(get(AX(1),'Ylabel'),'Color','k') 
set(get(AX(2),'Ylabel'),'Color','r') 
set(AX(1),'YColor','k') 
set(AX(2),'YColor','r') 
%set(H2,'Marker','.')
%xlim([1989 2014]);

subplot(2,1,2)
[AX, H1, H2] = plotyy(times, micro_struct(:,1,1,1,1),  times, exp(macrodata(:,2)), 'plot');
set(get(AX(1),'Ylabel'),'String','Frequency of sales') 
set(get(AX(2),'Ylabel'),'String','Hours worked') 
set(H1,'LineStyle','-')
set(H2,'LineStyle','-')
set(H1, 'LineWidth', 2);
set(H1, 'Color', 'k');
set(H2, 'Color', 'r');
set(get(AX(1),'Ylabel'),'Color','k') 
set(get(AX(2),'Ylabel'),'Color','r') 
set(AX(1),'YColor','k') 
set(AX(2),'YColor','r') 
%set(H2,'Marker','.')
%xlim([1989 2014]);


